*******************************************************
Adaptable IO beyond files in Scientific Data Lifecycles
*******************************************************

Performant and usable tools for data management at scale are essential in an era where scientific breakthroughs are collaborative, multidisciplinary, and computational.
ADIOS2 is an *adaptable*, *scalable*, and *unified* framework to aid scientific applications when data transfer volumes exceed the capabilities of traditional file I/O.

.. image:: https://i.imgur.com/VLSvvjM.png : alt: my-picture1


ADIOS2 provides


* Custom application management of massive data sets, starting from generation, analysis, and movement, as well as short-term and long-term storage.

* Self-describing data in binary-packed (`.bp`) format for rapid metadata extraction

* An ability to separate and extract relevant information from large data sets

* The capability to make real-time decisions based on in-transit or in-situ analytics

* The ability to expand to other transport mechanisms such wide area networks, remote direct memory access, and shared memory, with minimal overhead

* The ability to utilize the full capabilities of emergent hardware technologies, such as high-bandwidth memory and burst buffers
